import numpy as np

# Este es un módulo con funciones que saludan
def saludar():
	print("Hola, te estoy saludando desde la función saludar() del módulo saludos")

def prueba():
	print("Esto es una nueva prueba de la nueva Version 6.0")

def generar_array(numeros):
	return np.arange(numeros)



class Saludo():
	def __init__(self):
		print("Hola, te estoy saludando desde el __init__ de la clase Saludo")

if __name__ == '__main__':
	print(generar_array(5))



from struct import pack
from setuptools import setup, find_packages


setup(
     name="Mensajes",
    version="3.00",
    description="Un paquete para saludar y despedir",
    author="Hector Costa",
    author_email="hola@hektorprofe.com",
    url="http://www.hektorprofe.net",
    packages=find_packages(), # importando el find_pakages el programa buscara toos lo que esta dentro del paquete.
    scripts=['test.py'],
    install_requires=['numpy']
)



from struct import pack
from setuptools import setup, find_packages


setup(
    name="Mensajes-crispal",
    version="6.00",
    description="Un paquete para saludar y despedir",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="Hector Costa",
    author_email="hola@hektorprofe.com",
    url="http://www.hektorprofe.net",
    license_files=['LICENSE'],
    packages=find_packages(), # importando el find_pakages el programa buscara toos lo que esta dentro del paquete.
    scripts=[],
    test_suite='tests',
    install_requires=[paquete.strip() 
                        for paquete in open("requirements.txt").readlines()],
    classifiers=[
        'Environment :: Console', # Para consola pc
        'Intended Audience :: Developers', # La audiencia serian desarrolladores
        'License :: OSI Approved :: MIT License',# lisencia MIT
        'Operating System :: OS Independent', # Sistema operativo, independiente porque funciona en todos
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.9',
        'Topic :: Utilities', # topico utilidades
    ],
)
